==> vstutils-5.0.0b87-py3-none-any.whl: vstutils/translations/cn.py <==
# flake8: noqa: E501
TRANSLATION = {
    "new": '新的',
    "Create": '建立',
    "add": '增加',
    "Edit": '校对',
    "edit": '校对',
    "Save": '储存',
    "Remove": '删除',
    "Reload": '重启',
    "send": '发送',
    "select": '选择',
    "filters": '过滤',
    "apply": '应用',
    "cancel": '取消',
    "field": '范围',
    "actions": '活动',
    "sublinks": '输入链接',
    "name": '种类',
    "type": '类型',
    "owner": '业主',
    "notes": '标记',
    "copy": '复制',
    "error": '错误',
    "home": '主要的',
    "login": '进入',
    "logout": '退出',
    "Profile": '轮廓',
    "settings": '设置',
    "Settings": '设置',
    "version": '版本',
    "cache": '隐藏',
    "documentation": '文件',
    "request": '询问',
    "repository": '复位器',
    "app info": '信息',
    "status": '状态',
    "List is empty": '空白表格',
    "child instances": '输入对象',
    "enter value": '输入意义',
    "more info": '输入价值',
    "search by": '更详尽',
    'Search': '搜索 ',
    'Selected': '选中',
    'Nothing found!': '没有发现！',

    # x-menu generic
    'system': '范围查找',
    'users': '系统',
    'Is active': '活跃度',
    'Is staff': '减速装置',

    # multiactions button
    'actions on': '行动结束',
    'on item': '元素| 元素| 元素| 元素',

    'key': '要素',
    'value': '意义',
    'new owner': '新业主',
    'detail': '细节',
    'description': '描述',
    'username': '使用者',
    'is active': '活跃度',
    'user': '使用者',
    'yes': '是',
    'no': '否',
    'is staff': '管理',
    'first name': '名字',
    'last name': '姓',
    'password': '密码',
    'Password': '密码',
    'Change password': '变换密码',
    'Change_password': '变换密码',
    'generate password': '形成密码',
    'repeat password': '重复密码',
    'Repeat password': '重复密码',
    'Old password': '旧密码',
    'New password': '新密码',
    'Confirm new password': '确认密码',
    'kind': '类型',
    'mode': '制度',
    'options': '选项',
    'information': '信息',
    'date': '日期',

    'file n selected': '未选择文件| 已选择1个文件| 已选择{n}个文件| 已选择{n}个文件',
    'image n selected': '未选择图像 已选择1张图片| 已选择{n}张图片| 已选择{n}张图片',

    # filters
    'Ordering': '排列顺序',
    'is_active': '活跃度',
    'Username': '使用名',
    'First name': '名字',
    'Last name': '姓',

    # filters description
    'boolean value meaning status of user.': '指示用户状态的布尔值。',
    'users first name.': '用户名',
    'users last name.': '用户姓',
    'users e-mail value.': '用户邮箱',
    'which field to use when ordering the results.': '结果排序依据的字段',
    'a unique integer value (or comma separated list) identifying this instance.': '标识此对象的唯一数值（或用逗号分隔的序列）识别此对象',
    'a name string value (or comma separated list) of instance.': '对象名称-字符串值（或它们的顺序，用逗号分隔）',

    'Page matching current url was not found': '找不到与指定网址匹配的页面',
    'Unknown error': '未知错误',
    'Error': '错误',

    'sign in to start your session': '登录开始会议',
    'sign in': '进入',
    'sign up': '请注册',
    'forgot password': '忘记密码',
    'confirm password': '确认密码',
    'register': '注册',
    'fields with * is required': '标有*为必填项',
    'Forgot your password? Enter your email address below, and an email with instructions for setting a new one will be sent.': '忘记密码了吗？ 输入您的地址，我们将向您发送恢复指示',
    'reset my Password': '问密码',
    'We\'ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.': '我们已向您发送了一封电子邮件，其中包含有关重设密码的说明',
    'If you don\'t receive an email, please make sure you\'ve entered the address you registered with, and check your spam folder.': '如果您尚未收到电子邮件，请确认输入正确的地址并检查垃圾邮件文',
    'The password reset link was invalid, possibly because it has already been used. Please request a new Password reset.': '无效的密码恢复链接，可能已被使用。 请再试一次。',
    'Please enter your new password twice so we can verify you typed it in correctly.': '请输入新密码',
    'change my password': '换密码',
    'Your password has been set.  You may go ahead and log in now.': '您的密码已成功设置。 您现在可以登录',
    'Please enter a correct %(username)s and password. Note that both fields may be case-sensitive.': '请输入正确的％（用户名）和密码。 注意，这些字段可能区分大小写',
    'or': '或者',
    'two-factor authentication code': '两因素授权码',
    'verify code': '确认密码',
    'Enter the code from the two-factor app on your mobile device. If you\'ve lost your device, you may enter one of your recovery codes.': '从您的移动设备上的两个应用程序中输入代码。 如果您丢失了设备，则可以输入恢复其中一个代码',
    'Invalid authentication code': '无效的授权码',
    'Scan the image with the two-factor authentication app on your phone. If you can’t use a barcode, enter this text code instead.': '使用手机上的两个身份验证应用程序扫描图像。 如果您不能使用条形码，请输入文本代码。',
    'Enter the six-digit code from the application': '从应用程序中输入六个字符的代码',
    'code': '代码',
    'recovery codes': '恢复代码',
    'Recovery codes are used to access your account in the event you cannot receive two-factor authentication codes.': '如果您无法获得两个身份验证码，则可以使用恢复码来访问您的帐户。',
    'Disabling Two-Factor Authentication (2FA) will decrease your account\'s security': '禁用两个身份验证会降低您帐户的安全性',
    'Enable': '打开',
    'Disable': '关闭',
    'Two factor authentication': '两个验证',
    'No {0} matches the given query.': '{0}没有一个与此请求匹配',
    'Password is not correct.': '密码不正确',
    'New passwords values are not equal.': '新密码值不相同',
    'This password is entirely numeric.': '该密码应使用完全数字',
    'Passwords do not match.': '密码不匹配。',
    "The two password fields didn't match.": '两个密码字段不匹配。',
    'Dark theme': '黑色主题',
    'Language': '语言',
    'height': '高度',
    'width': '宽度',
    'More info': '更多信息',
    'Dark mode': '黑暗主题',
    'Execute': '施行',
    'Domain should be setuped or username should be with @domain.name': "应设置域或用户名应为@domain.name",
    'Invalid name': '无效名称',
    'Should be [full.domain.name]': '应该是 [full.domain.name].',
    'Invalid registration email send.': '无效的注册电子邮件发送。',
    'To continue, need to accept the terms agreement.': '要继续，需要接受条款协议。',


    # Проверить
    'Changes in settings are successfully saved. Please refresh the page.': '设置更改已成功保存。 请刷新页面。',
    'now': '眼下',
    'later': '之后',
    'i accept the ': '我接受 ',
    'Zoom': '飛漲',
    'Scale': '規模',
    'This file format is not supported': '不支持此文件格式',
    'Oops! Something went wrong.': '哎呀！ 出了些问题。',
    '[Object not found]': '[未找到对象]',
    'Execute action on {0}': '在 {0} 上执行操作',
    '{n} instance': '{n} 个实例',
    'Open image': '打开图片',

    # field's validation
    # empty
    'Field "<b>{0}</b>" is empty.': '范围"<b>{0}</b>" 是空的',
    # required
    'Field "<b>{0}</b>" is required.': '范围"<b>{0}</b>" 必须完成',
    # minLength
    'Field "<b>{0}</b>" is too short.<br> Field length should not be shorter, then {1}.': '长度范围 "<b>{0}</b>" 太少.<br>长度范围应不少于{1}.',
    # maxLength
    'Field "<b>{0}</b>" is too long. <br> Field length should not be longer, then {1}.': '长度单位"<b>{0}</b>" 太大<br>长度单位 应不大于{1}.',
    # min
    'Field "<b>{0}</b>" is too small.<br> Field should not be smaller, then {1}.': '取值范围 "<b>{0}</b>" 太少.<br> 取值范围应不少于 {1}.',
    # max
    'Field "<b>{0}</b>" is too big.<br> Field should not be bigger, then {1}.': '取值范围 "<b>{0}</b>" 太大.<br> 取值范围应不大于{1}.',
    # invalid
    '<b>{0} </b> value is not valid for <b>{1}</b> field.': '不能在 <b>{1}</b>取值为<b>{0}</b> .',
    # email
    '<b>"{0}"</b> field should be written in <b>"example@mail.com"</b> format.': '应在 <b>"example@mail.com"</b>.范围内完成<b>"{0}"</b>',

    # validators
    'imageValidationResolutionError': "必须至少为{min}且不超过{max}个像素",

    # instance operation success
    # add
    'Child "<b>{0}</b>" instance was successfully added to parent list.': '子对象“ <b> {0} </ b>”已成功添加到母列表中.',
    # create
    'New "<b>{0}</b>" instance was successfully created.': '新对象“ <b> {0} </ b>”已成功创建.',
    # remove
    '"<b>{0}</b>" {1} was successfully removed.': '"<b>{0}</b>" {1} 已成功删除."',
    # save
    'Changes in "<b>{0}</b>" {1} were successfully saved.': '对象变化{1}“ <b> {0} </ b>”的更改已成功保存.',
    # execute
    'Action "<b>{0}</b>" was successfully executed on "<b>{1}</b>" instance.': '在对象“ <b> {1} </ b>”上成功启动了操作“ <b> {0} </ b>”。',
    # instance operation error
    # add:
    'An error occurred during adding of child "<b>{0}</b>" instance to parent list.<br> Error details: {1}': '将对象“ <b> {0} </ b>”添加到目级列表时发生错误。<br>更多详细信息：{1}',
    # create:
    'An error occurred during creation.<br>Error details:<br>{0}': '创建新对象时发生错误<br>更多详细信息：{0}',
    # remove:
    'An error occurred during removal process of "<b>{0}</b>" {1}.<br> Error details: {2}': '删除{1}“ <b> {0} </ b>”时发生错误<br>更多详细信息：{2}',
    # save:
    'An error occurred during process.<br>Error details:<br>{0}': '保存时发生错误。<br>更多详细信息：{0}',
    # execute:
    'An error occurred during <b>{0}</b>. Error details:<br>{1}': '<b>{0}</b> 期间发生了一些错误。 错误详情：<br>{1}',
    'Link': '链接',
}

SERVER_TRANSLATION = {
    # field's validation
    "value is not a valid list": "值不是有效列表",
    "value is not a valid JSON": "值不是有效的 JSON",
    "key {missing_key} is missing": "缺少密钥 {missing_key}",
    "invalid key {invalid_key}": "无效密钥 {invalid_key}",

    # validators
    'unsupported image file format, expected ({0}), got {1}': '不支持的图像格式，支持（{0}），已收到{1}',
    'For some reason, this image file cannot be opened': '无法打开图像文件',
    'Invalid image {0}. Expected from {1} to {2}, got {3}': "{0}图片不正确。 预期从{1}到{2}，收到{3}",
    'This field must contain only digits but input: ': '此字段必须仅包含数字但输入：',
    'Unsupported image file format': '不支持的图像文件格式',
    'is not in listed supported types': '不在列出的受支持类型中',
    'Invalid image size orientations': '图片尺寸不正确',
    'Current image size': '当前图像大小',

    # agreements
    'personal data processing policy': '个人资料处理政策',
    'i agree with ': '我同意 ',
    'the personal data processing policy': '个人资料处理政策',
    'To continue, need to agree to the personal data processing policy.': '要继续，需要同意个人数据处理政策。',
    'terms of agreement': '协议条款',
}

==> vstutils-5.1.11-py3-none-any.whl: vstutils/translations/cn.py <==
# flake8: noqa: E501
TRANSLATION = {
    "new": '新的',
    "Create": '建立',
    "add": '增加',
    "Edit": '校对',
    "edit": '校对',
    "Save": '储存',
    "Remove": '删除',
    "Reload": '重启',
    "send": '发送',
    "select": '选择',
    "filters": '过滤',
    "apply": '应用',
    "cancel": '取消',
    "field": '范围',
    "actions": '活动',
    "sublinks": '输入链接',
    "name": '种类',
    "type": '类型',
    "owner": '业主',
    "notes": '标记',
    "copy": '复制',
    "error": '错误',
    "home": '主要的',
    "login": '进入',
    "logout": '退出',
    "Profile": '轮廓',
    "settings": '设置',
    "Settings": '设置',
    "version": '版本',
    "cache": '隐藏',
    "documentation": '文件',
    "request": '询问',
    "repository": '复位器',
    "app info": '信息',
    "status": '状态',
    "List is empty": '空白表格',
    "child instances": '输入对象',
    "enter value": '输入意义',
    "more info": '输入价值',
    "search by": '更详尽',
    'Search': '搜索 ',
    'Selected': '选中',
    'Nothing found!': '没有发现！',
    'Main settings': '主要设置',
    'Custom settings': '自定义设置',
    'Remove from list': '從列表中刪除',
    'Purge': '刪除',
    'Select an action for this instances': '為此實例選擇一個操作',
    'Username not': '用户名不是',
    'Download file': '下载文件',
    'File list': '文件列表',
    'Select file': '选择文件',
    'Select files': '选择文件',
    'Clear field': '清场',
    'Column is required!': '列是必需的!',

    # fields
    'Id': '标识符',
    'ID': '标识符',

    # x-menu generic
    'system': '范围查找',
    'users': '系统',
    'Is active': '活跃度',
    'Is staff': '减速装置',

    # multiactions button
    'actions on': '行动结束',
    'on item': '元素| 元素| 元素| 元素',

    'key': '要素',
    'value': '意义',
    'new owner': '新业主',
    'detail': '细节',
    'description': '描述',
    'username': '使用者',
    'is active': '活跃度',
    'user': '使用者',
    'yes': '是',
    'no': '否',
    'Yes': '是',
    'No': '否',
    'is staff': '管理',
    'first name': '名字',
    'last name': '姓',
    'password': '密码',
    'Password': '密码',
    'Change password': '变换密码',
    'Change_password': '变换密码',
    'generate password': '形成密码',
    'repeat password': '重复密码',
    'Repeat password': '重复密码',
    'Old password': '旧密码',
    'New password': '新密码',
    'Confirm new password': '确认密码',
    'kind': '类型',
    'mode': '制度',
    'options': '选项',
    'information': '信息',
    'date': '日期',
    'Your changes will be deleted. Are you sure?': '您的更改将被删除。你确定吗？',

    'file n selected': '未选择文件| 已选择1个文件| 已选择{n}个文件| 已选择{n}个文件',
    'image n selected': '未选择图像 已选择1张图片| 已选择{n}张图片| 已选择{n}张图片',

    # filters
    'Ordering': '排列顺序',
    'is_active': '活跃度',
    'Username': '使用名',
    'First name': '名字',
    'Last name': '姓',

    'Page matching current url was not found': '找不到与指定网址匹配的页面',
    'Unknown error': '未知错误',
    'Error': '错误',

    'We\'ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.': '我们已向您发送了一封电子邮件，其中包含有关重设密码的说明',
    'If you don\'t receive an email, please make sure you\'ve entered the address you registered with, and check your spam folder.': '如果您尚未收到电子邮件，请确认输入正确的地址并检查垃圾邮件文',
    'The password reset link was invalid, possibly because it has already been used. Please request a new Password reset.': '无效的密码恢复链接，可能已被使用。 请再试一次。',
    'Please enter your new password twice so we can verify you typed it in correctly.': '请输入新密码',
    'change my password': '换密码',
    'Your password has been set.  You may go ahead and log in now.': '您的密码已成功设置。 您现在可以登录',
    'Please enter a correct %(username)s and password. Note that both fields may be case-sensitive.': '请输入正确的％（用户名）和密码。 注意，这些字段可能区分大小写',
    'or': '或者',
    'two-factor authentication code': '两因素授权码',
    'verify code': '确认密码',
    'Enter the code from the two-factor app on your mobile device. If you\'ve lost your device, you may enter one of your recovery codes.': '从您的移动设备上的两个应用程序中输入代码。 如果您丢失了设备，则可以输入恢复其中一个代码',
    'Scan the image with the two-factor authentication app on your phone. If you can’t use a QR code, enter this text code instead.': '使用手机上的双重身份验证应用程序扫描图像。 如果您不能使用二维码，请输入此文本代码。',
    'Enter the six-digit code from the application': '从应用程序中输入六个字符的代码',
    'code': '代码',
    'recovery codes': '恢复代码',
    'Recovery codes are used to access your account in the event you cannot receive two-factor authentication codes.': '如果您无法获得两个身份验证码，则可以使用恢复码来访问您的帐户。',
    'Disabling Two-Factor Authentication (2FA) will decrease your account\'s security': '禁用两个身份验证会降低您帐户的安全性',
    'Enable': '打开',
    'Disable': '关闭',
    'Two factor authentication': '两个验证',
    'No {0} matches the given query.': '{0}没有一个与此请求匹配',
    'Password is not correct.': '密码不正确',
    'New passwords values are not equal.': '新密码值不相同',
    'This password is entirely numeric.': '该密码应使用完全数字',
    'Passwords do not match.': '密码不匹配。',
    "The two password fields didn't match.": '两个密码字段不匹配。',
    'Dark theme': '黑色主题',
    'Language': '语言',
    'height': '高度',
    'width': '宽度',
    'More info': '更多信息',
    'Dark mode': '黑暗主题',
    'Execute': '施行',
    'Domain should be setuped or username should be with @domain.name': "应设置域或用户名应为@domain.name",
    'Invalid name': '无效名称',
    'Should be [full.domain.name]': '应该是 [full.domain.name].',
    'Invalid registration email send.': '无效的注册电子邮件发送。',
    'To continue, need to accept the terms agreement.': '要继续，需要接受条款协议。',
    'Clear all cache with settings': '使用设置清除所有缓存',
    'Generate password': '生成密码',


    # Проверить
    'Changes in settings are successfully saved. Please refresh the page.': '设置更改已成功保存。 请刷新页面。',
    'Do you want to save your changes? The page will be reloaded.': '是否要保存更改？ 该页面将重新加载。',
    'Reload now': '立即重新加载',
    'now': '眼下',
    'later': '之后',
    'Later': '之后',
    'I accept the ': '我接受 ',
    'Zoom': '飛漲',
    'Scale': '規模',
    'Rotate': '旋转',
    'Crop': '庄稼',
    'This file format is not supported': '不支持此文件格式',
    'Oops! Something went wrong.': '哎呀！ 出了些问题。',
    '[Object not found]': '[未找到对象]',
    'Execute action on {0}': '在 {0} 上执行操作',
    '{n} instance': '{n} 个实例',
    'Open image': '打开图片',
    'Confirm action': '确认操作',
    'Confirm': '确认',
    'Cancel': '取消',

    # field's validation
    # empty
    'Field "<b>{0}</b>" is empty.': '范围"<b>{0}</b>" 是空的',
    # required
    'Field "<b>{0}</b>" is required.': '范围"<b>{0}</b>" 必须完成',
    # minLength
    'Field "<b>{0}</b>" is too short.<br> Field length should not be shorter, then {1}.': '长度范围 "<b>{0}</b>" 太少.<br>长度范围应不少于{1}.',
    # maxLength
    'Field "<b>{0}</b>" is too long. <br> Field length should not be longer, then {1}.': '长度单位"<b>{0}</b>" 太大<br>长度单位 应不大于{1}.',
    # min
    'Field "<b>{0}</b>" is too small.<br> Field should not be smaller, then {1}.': '取值范围 "<b>{0}</b>" 太少.<br> 取值范围应不少于 {1}.',
    # max
    'Field "<b>{0}</b>" is too big.<br> Field should not be bigger, then {1}.': '取值范围 "<b>{0}</b>" 太大.<br> 取值范围应不大于{1}.',
    # invalid
    '<b>{0} </b> value is not valid for <b>{1}</b> field.': '不能在 <b>{1}</b>取值为<b>{0}</b> .',
    # email
    '<b>"{0}"</b> field should be written in <b>"example@mail.com"</b> format.': '应在 <b>"example@mail.com"</b>.范围内完成<b>"{0}"</b>',

    # validators
    'imageValidationResolutionError': "必须至少为{min}且不超过{max}个像素",

    # instance operation success
    # add
    'Child "<b>{0}</b>" instance was successfully added to parent list.': '子对象“ <b> {0} </ b>”已成功添加到母列表中.',
    # create
    'New "<b>{0}</b>" instance was successfully created.': '新对象“ <b> {0} </ b>”已成功创建.',
    # remove
    '"<b>{0}</b>" {1} was successfully removed.': '"<b>{0}</b>" {1} 已成功删除."',
    # save
    'Changes in "<b>{0}</b>" {1} were successfully saved.': '对象变化{1}“ <b> {0} </ b>”的更改已成功保存.',
    # execute
    'Action "<b>{0}</b>" was successfully executed on "<b>{1}</b>" instance.': '在对象“ <b> {1} </ b>”上成功启动了操作“ <b> {0} </ b>”。',
    # instance operation error
    # add:
    'An error occurred during adding of child "<b>{0}</b>" instance to parent list.<br> Error details: {1}': '将对象“ <b> {0} </ b>”添加到目级列表时发生错误。<br>更多详细信息：{1}',
    # create:
    'An error occurred during creation.<br>Error details:<br>{0}': '创建新对象时发生错误<br>更多详细信息：{0}',
    # remove:
    'An error occurred during removal process of "<b>{0}</b>" {1}.<br> Error details: {2}': '删除{1}“ <b> {0} </ b>”时发生错误<br>更多详细信息：{2}',
    # save:
    'An error occurred during process.<br>Error details:<br>{0}': '保存时发生错误。<br>更多详细信息：{0}',
    # execute:
    'An error occurred during <b>{0}</b>. Error details:<br>{1}': '<b>{0}</b> 期间发生了一些错误。 错误详情：<br>{1}',
    'Link': '链接',

    # csv
    'Actions': '行動',
    'Index': '指數',
    'Download with headers': '帶標題下載',
    'Changes you made may not be saved.': '您所做的更改可能不会保存。',
}

SERVER_TRANSLATION = {
    # field's validation
    "value is not a valid list": "值不是有效列表",
    "value is not a valid JSON": "值不是有效的 JSON",
    "key {missing_key} is missing": "缺少密钥 {missing_key}",
    "invalid key {invalid_key}": "无效密钥 {invalid_key}",
    "Invalid {period} range. Valid choices in {valid} range.": "{period} 范围无效。 {valid} 范围内的有效选择。",
    "Invalid delimiter value in {interval}. Must be integer.": "{interval} 中的分隔符值无效。 必须是整数。",
    "There are to many columns with crontab values.": "有很多列带有 crontab 值。",
    "Invalid crontab syntax.": "无效的 crontab 语法。",

    # field help_text
    'A confirmation will be sent to your e-mail': '确认将发送到您的电子邮箱',
    'Required. Inform a valid email address': '必需的。 通知一个有效的电子邮件地址',

    # validators
    'unsupported image file format, expected ({0}), got {1}': '不支持的图像格式，支持（{0}），已收到{1}',
    'For some reason, this image file cannot be opened': '无法打开图像文件',
    'Invalid image {0}. Expected from {1} to {2}, got {3}': "{0}图片不正确。 预期从{1}到{2}，收到{3}",
    'This field must contain only digits but input: ': '此字段必须仅包含数字但输入：',
    'Unsupported image file format': '不支持的图像文件格式',
    'is not in listed supported types': '不在列出的受支持类型中',
    'Invalid image size orientations': '图片尺寸不正确',
    'Current image size': '当前图像大小',

    # agreements
    'personal data processing policy': '个人资料处理政策',
    'I agree with ': '我同意 ',
    'the personal data processing policy': '个人资料处理政策',
    'To continue, need to agree to the personal data processing policy.': '要继续，需要同意个人数据处理政策。',
    'terms of agreement': '协议条款',

    #auth/reg
    'sign in to start your session': '登录开始会议',
    'confirm your email before logging in': '登录前确认您的电子邮件',
    'Confirmation link is invalid or expired': '确认链接无效或过期',
    'sign in': '进入',
    'sign up': '请注册',
    'forgot password': '忘记密码',
    'confirm password': '确认密码',
    'register': '注册',
    'fields with * is required': '标有*为必填项',
    'Forgot your password? Enter your email address below, and an email with instructions for setting a new one will be sent.': '忘记密码了吗？ 输入您的地址，我们将向您发送恢复指示',
    'reset my Password': '问密码',
    'Invalid authentication code': '无效的授权码',
    'Secret string must be provided': '必须提供秘密字符串',

    # filters help text
    'A unique integer value (or comma separated list) identifying this instance.': '标识此对象的唯一数值（或用逗号分隔的序列）识别此对象',
    'A name string value (or comma separated list) of instance.': '对象名称-字符串值（或它们的顺序，用逗号分隔）',
    'Which field to use when ordering the results.': '结果排序依据的字段',
    "Search by {}'s primary key or {}": '按 {} 的主键或 {} 搜索',
    '_name': '种类',
    'Boolean value meaning status of user.': '指示用户状态的布尔值。',
    'Users first name.': '用户名',
    'Users last name.': '用户姓',
    'Users e-mail value.': '用户邮箱',
}
